@@ -3,20 +3,6 @@
  *
  * Sven Eckelmann <sven@narfation.org>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA
- *
  * License-Filename: LICENSES/preferred/GPL-2.0
  */
 
@@ -284,6 +270,10 @@ static void event_parse_set_mesh(struct nlattr **attrs)
 		printf("* log_level 0x%08x\n",
 		       nla_get_u32(attrs[BATADV_ATTR_LOG_LEVEL]));
 
+	if (attrs[BATADV_ATTR_MULTICAST_FANOUT])
+		printf("* multicast_fanout %u\n",
+		       nla_get_u32(attrs[BATADV_ATTR_MULTICAST_FANOUT]));
+
 	if (attrs[BATADV_ATTR_MULTICAST_FORCEFLOOD_ENABLED])
 		printf("* multicast_forceflood %s\n",
 		       u8_to_boolstr(attrs[BATADV_ATTR_MULTICAST_FORCEFLOOD_ENABLED]));
